==> rextendr_0.3.1.tar.gz: rextendr/tests/testthat/_snaps/license_note.md <==
# LICENSE.note is generated properly

    Code
      cat_file("LICENSE.note")
    Output
      The binary compiled from the source code of this package contains the following Rust crates:
      
      
      -------------------------------------------------------------
      
      Name:        extendr-api
      Repository:  https://github.com/extendr/extendr
      Authors:     andy-thomason, Thomas Down, Mossa Merhi Reimert, Claus O. Wilke, Hiroaki Yutani, Ilia A. Kosenkov, Michael Milton
      License:     MIT
      
      -------------------------------------------------------------
      
      Name:        extendr-engine
      Repository:  https://github.com/extendr/extendr
      Authors:     andy-thomason, Thomas Down, Mossa Merhi Reimert, Claus O. Wilke, Hiroaki Yutani, Ilia A. Kosenkov
      License:     MIT
      
      -------------------------------------------------------------
      
      Name:        extendr-macros
      Repository:  https://github.com/extendr/extendr
      Authors:     andy-thomason, Thomas Down, Mossa Merhi Reimert, Claus O. Wilke, Hiroaki Yutani, Ilia A. Kosenkov
      License:     MIT
      
      -------------------------------------------------------------
      
      Name:        lazy_static
      Repository:  https://github.com/rust-lang-nursery/lazy-static.rs
      Authors:     Marvin Löbel
      License:     Apache-2.0 OR MIT
      
      -------------------------------------------------------------
      
      Name:        libR-sys
      Repository:  https://github.com/extendr/libR-sys
      Authors:     andy-thomason, Thomas Down, Mossa Merhi Reimert, Claus O. Wilke, Ilia A. Kosenkov, Hiroaki Yutani
      License:     MIT
      
      -------------------------------------------------------------
      
      Name:        paste
      Repository:  https://github.com/dtolnay/paste
      Authors:     David Tolnay
      License:     Apache-2.0 OR MIT
      
      -------------------------------------------------------------
      
      Name:        proc-macro2
      Repository:  https://github.com/dtolnay/proc-macro2
      Authors:     David Tolnay, Alex Crichton
      License:     Apache-2.0 OR MIT
      
      -------------------------------------------------------------
      
      Name:        quote
      Repository:  https://github.com/dtolnay/quote
      Authors:     David Tolnay
      License:     Apache-2.0 OR MIT
      
      -------------------------------------------------------------
      
      Name:        syn
      Repository:  https://github.com/dtolnay/syn
      Authors:     David Tolnay
      License:     Apache-2.0 OR MIT
      
      -------------------------------------------------------------
      
      Name:        unicode-ident
      Repository:  https://github.com/dtolnay/unicode-ident
      Authors:     David Tolnay
      License:     (MIT OR Apache-2.0) AND Unicode-DFS-2016
      
      -------------------------------------------------------------

==> rextendr_0.4.1.tar.gz: rextendr/tests/testthat/_snaps/license_note.md <==
# LICENSE.note is generated properly

    Code
      cat_file("LICENSE.note")
    Output
      The binary compiled from the source code of this package contains the following Rust crates:
      
      
      -------------------------------------------------------------
      
      Name:        build-print
      Repository:  NA
      Authors:     sam0x17
      License:     MIT
      
      -------------------------------------------------------------
      
      Name:        extendr-api
      Repository:  https://github.com/extendr/extendr
      Authors:     andy-thomason, Thomas Down, Mossa Merhi Reimert, Josiah Parry, Claus O. Wilke, Hiroaki Yutani, Ilia A. Kosenkov, Michael Milton
      License:     MIT
      
      -------------------------------------------------------------
      
      Name:        extendr-ffi
      Repository:  https://github.com/extendr/extendr
      Authors:     andy-thomason, Thomas Down, Mossa Merhi Reimert, Josiah Parry, Claus O. Wilke, Hiroaki Yutani, Ilia A. Kosenkov, Michael Milton
      License:     MIT
      
      -------------------------------------------------------------
      
      Name:        extendr-macros
      Repository:  https://github.com/extendr/extendr
      Authors:     andy-thomason, Thomas Down, Mossa Merhi Reimert, Josiah Parry, Claus O. Wilke, Hiroaki Yutani, Ilia A. Kosenkov, Michael Milton
      License:     MIT
      
      -------------------------------------------------------------
      
      Name:        once_cell
      Repository:  https://github.com/matklad/once_cell
      Authors:     Aleksey Kladov
      License:     MIT OR Apache-2.0
      
      -------------------------------------------------------------
      
      Name:        paste
      Repository:  https://github.com/dtolnay/paste
      Authors:     David Tolnay
      License:     MIT OR Apache-2.0
      
      -------------------------------------------------------------
      
      Name:        proc-macro2
      Repository:  https://github.com/dtolnay/proc-macro2
      Authors:     David Tolnay, Alex Crichton
      License:     MIT OR Apache-2.0
      
      -------------------------------------------------------------
      
      Name:        quote
      Repository:  https://github.com/dtolnay/quote
      Authors:     David Tolnay
      License:     MIT OR Apache-2.0
      
      -------------------------------------------------------------
      
      Name:        syn
      Repository:  https://github.com/dtolnay/syn
      Authors:     David Tolnay
      License:     MIT OR Apache-2.0
      
      -------------------------------------------------------------
      
      Name:        unicode-ident
      Repository:  https://github.com/dtolnay/unicode-ident
      Authors:     David Tolnay
      License:     (MIT OR Apache-2.0) AND Unicode-3.0
      
      -------------------------------------------------------------
